Results of a sequence of independent runs of an EDA. This class is just a
wrapper for a list object containing '>EDAResult
instances. Objects are created by calling the edaIndepRuns
function.
signature(object = "EDAResults"): Prints a table with
the results.
signature(object = "EDAResults"): Prints a summary
of the results.
Gonzalez-Fernandez Y, Soto M (2014). copulaedas: An R Package for Estimation of Distribution Algorithms Based on Copulas. Journal of Statistical Software, 58(9), 1-34. http://www.jstatsoft.org/v58/i09/.
'>EDA,
edaIndepRuns.